# definedge_lib

A Python library for Definedge trading strategies.

## Installation

```bash
pip install tamingnifty
```

## Usage

```python
from tamingnifty import ta
```

## Features

- Connect to Definedge API
- Utilities for trading strategies
- Conversion to Renko or Point and Figure charts
- Tick streaming

## License

MIT